==> invoice-client-4.1.42-20221026.091035-14-sources.jar: com/xforceplus/seller/invoice/client/model/SellerPreInvoiceSplitRuleChangeResult.java <==
package com.xforceplus.seller.invoice.client.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.ArrayList;
import java.util.List;

/**
 * @ClassName SellerPreInvoiceSplitRuleChangeResult
 * @Author zhangxiaolong
 * @Date 2019/3/7
 * @Version 1.0
 **/
@Data
public class SellerPreInvoiceSplitRuleChangeResult {

    @JsonProperty("conifgItemDataDTOs")
    @ApiModelProperty(value = "拆票规则配置明细")
    private List<ConifgItemDataDTO> conifgItemDataDTOs = new ArrayList();
    @JsonProperty("template")
    @ApiModelProperty(value = "拆票规则元数据对象")
    private List<MsBusinessObjMetadataBean> template = new ArrayList();

    @JsonProperty("batchNo")
    @ApiModelProperty(value = "批次号")
    private String batchNo;

    @ApiModelProperty(value = "全电税号集合")
    private List<String> allElectricTaxNoList;
//
//    public List<ConifgItemDataDTO> getConifgItemDataDTOs() {
//        return conifgItemDataDTOs;
//    }
//
//    public void setConifgItemDataDTOs(List<ConifgItemDataDTO> conifgItemDataDTOs) {
//        this.conifgItemDataDTOs = conifgItemDataDTOs;
//    }
//
//    public List<MsBusinessObjMetadataBean> getTemplate() {
//        return template;
//    }
//
//    public void setTemplate(List<MsBusinessObjMetadataBean> template) {
//        this.template = template;
//    }
//
//    public String getBatchNo() {
//        return batchNo;
//    }
//
//    public void setBatchNo(String batchNo) {
//        this.batchNo = batchNo;
//    }
}

==> invoice-client-4.1.54-20231213.034158-4-sources.jar: com/xforceplus/seller/invoice/client/model/SellerPreInvoiceSplitRuleChangeResult.java <==
package com.xforceplus.seller.invoice.client.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.ArrayList;
import java.util.List;

/**
 * @ClassName SellerPreInvoiceSplitRuleChangeResult
 * @Author zhangxiaolong
 * @Date 2019/3/7
 * @Version 1.0
 **/
@Data
public class SellerPreInvoiceSplitRuleChangeResult {

    @JsonProperty("conifgItemDataDTOs")
    @ApiModelProperty(value = "拆票规则配置明细")
    private List<ConifgItemDataDTO> conifgItemDataDTOs = new ArrayList();
    @JsonProperty("template")
    @ApiModelProperty(value = "拆票规则元数据对象")
    private List<MsBusinessObjMetadataBean> template = new ArrayList();

    @JsonProperty("batchNo")
    @ApiModelProperty(value = "批次号")
    private String batchNo;

    @ApiModelProperty(value = "数电税号集合")
    private List<String> allElectricTaxNoList;
//
//    public List<ConifgItemDataDTO> getConifgItemDataDTOs() {
//        return conifgItemDataDTOs;
//    }
//
//    public void setConifgItemDataDTOs(List<ConifgItemDataDTO> conifgItemDataDTOs) {
//        this.conifgItemDataDTOs = conifgItemDataDTOs;
//    }
//
//    public List<MsBusinessObjMetadataBean> getTemplate() {
//        return template;
//    }
//
//    public void setTemplate(List<MsBusinessObjMetadataBean> template) {
//        this.template = template;
//    }
//
//    public String getBatchNo() {
//        return batchNo;
//    }
//
//    public void setBatchNo(String batchNo) {
//        this.batchNo = batchNo;
//    }
}
